Generic object and connection pool.
This struct can be cloned and transferred across thread boundaries and uses
reference counting for its internal state.
Instantiates a builder for a new Pool.
This is the only way to create a Pool instance.
Retrieves an Object from this Pool or waits for one to
become available.
See PoolError for details.
Retrieves an Object from this Pool and doesn’t wait if there is
currently no Object available and the maximum Pool size has
been reached.
See PoolError for details.
Retrieves an Object from this Pool using a different timeout
than the configured one.
See PoolError for details.
Resize the pool. This change the max_size of the pool dropping
excess objects and/or making space for new ones.
If the pool is closed this method does nothing. The Pool::status method
always reports a max_size of 0 for closed pools.
Closes this Pool.
All current and future tasks waiting for Objects will return
PoolError::Closed immediately.
This operation resizes the pool to 0.
Indicates whether this Pool has been closed.
Performs copy-assignment from source. Read more
Formats the value using the given formatter. Read more
impl<T> Any for T where
T: 'static + ?Sized,
Immutably borrows from an owned value. Read more
Mutably borrows from an owned value. Read more
impl<T, U> Into<U> for T where
U: From<T>,
The resulting type after obtaining ownership.
Creates owned data from borrowed data, usually by cloning. Read more
🔬 This is a nightly-only experimental API. (toowned_clone_into)
recently added
Uses borrowed data to replace owned data, usually by cloning. Read more
The type returned in the event of a conversion error.
The type returned in the event of a conversion error.